%% set inputs for solution below
%  The program produces responses to the shocks selected below under
%  irfshock. Paths for all the endogenous variables in the model selected
%  are produced. VariableName_piecewise holds the piece-wise linear solution for
%  VariableName.  VariableName_linear holds the linear solution for
%  VariableName.
clear all
global M_ oo_

addpath('toolkit_files');
% modname below chooses model
% directory. But simple param choices are made from paramfile in current
% directory.
modnam = 'cz';
modnamstar = 'czlb';


% express the occasionally binding constraint
% in linearized form
% one can use any combination of endogenous variables and parameters 
% declared in the the dynare .mod files
constraint = 'r<-(1/betab-1)'; 
constraint_relax ='r_not>-(1/betab-1)';


% Pick innovation for IRFs
irfshock =char('epsilon_f_r' );      % label for innovation for IRFs
                             % needs to be an exogenous variable in the
                             % dynare .mod files

SHOCKS = [ zeros(1,1)
   -0.924  
 ] ;


shockssequence = SHOCKS;
nperiods = 60;
maxiter = 30;

% generate model IRFs
[zdatalinear zdatapiecewise zdatass oobase_ Mbase_  ] = ...
  solve_one_constraint(modnam,modnamstar,...
  constraint, constraint_relax,...
  shockssequence,irfshock,nperiods,maxiter);


                          
% unpack the IRFs                          
for i=1:Mbase_.endo_nbr
  eval([Mbase_.endo_names{i,:},'_linear=zdatalinear(:,i);']);
  eval([Mbase_.endo_names{i,:},'_piecewise=zdatapiecewise(:,i);']);
  eval([Mbase_.endo_names{i,:},'_ss=zdatass(i);']);
end

% Construct interest rate in levels
rlevel_ss=1/betab-1;
rlevel_piecewise=400*(r_piecewise+rlevel_ss);
rlevel_linear=400*(r_linear+rlevel_ss);



%% Modify to plot IRFs and decision rules

titlelist = char('r (Interest Rate)','p (Inflation)','y (Output)','g (Demand Shock)');


figtitle = '';
line1=[r_piecewise,pi_piecewise,y_piecewise,c_piecewise];
line2=[r_linear,pi_linear,y_linear,c_linear];


% Figure 1: Plot dynamic simulation
legendlist = cellstr(char('Piecewise Linear','Linear'));
ylabels = char('Percent Level, Annualized','Percent from ss, Annualized','Percent from ss','Percent from ss');
figlabel = '';
makechart(titlelist,legendlist,figlabel,ylabels,line1,line2)

